var plplotP_8h =
[
    [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", "structHershey__to__Unicode__table" ],
    [ "EscText", "structEscText.html", "structEscText" ],
    [ "DrvOpt", "structDrvOpt.html", "structDrvOpt" ],
    [ "cont_line", "structcont__line.html", "structcont__line" ],
    [ "cont_level", "structcont__level.html", "structcont__level" ],
    [ "arc_struct", "structarc__struct.html", "structarc__struct" ],
    [ "IMG_DT", "structIMG__DT.html", "structIMG__DT" ],
    [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", "structFCI__to__FontName__Table" ],
    [ "ABS", "plplotP_8h.html#ae2f08dc603ae93c402abd918ba4e23e1", null ],
    [ "BETW", "plplotP_8h.html#af6c78f36cb8594e9612e7acbcf28e8bb", null ],
    [ "DPMM", "plplotP_8h.html#abaf07295f4b55cf9e4f5f6b7139505ed", null ],
    [ "FALSE", "plplotP_8h.html#aa93f0eb578d23995850d61f7d61c55c1", null ],
    [ "FPOS_T", "plplotP_8h.html#a7e6aade5ce3529e2eb65b16311015e9b", null ],
    [ "free_mem", "plplotP_8h.html#af65d2391cbbf6daaedb72e9fe83078c6", null ],
    [ "GRAPHICS_MODE", "plplotP_8h.html#a44b886efaaef4628af9bdc4afc66568e", null ],
    [ "HUGE_VAL", "plplotP_8h.html#af2164b2db92d8a0ed3838ad5c28db971", null ],
    [ "isfinite", "plplotP_8h.html#a256d70a32c03904ce13c999c1e9dc35d", null ],
    [ "isinf", "plplotP_8h.html#a2a266c767456556e5c0da234b602b18b", null ],
    [ "isnan", "plplotP_8h.html#a2e1baae9134e580910322362dc23290e", null ],
    [ "LINE_ITEMS", "plplotP_8h.html#ad55f457dc600f6fa4269f175054f3c07", null ],
    [ "LPAGE_X", "plplotP_8h.html#a60aaec1096ee424ce937d81fdd957553", null ],
    [ "LPAGE_Y", "plplotP_8h.html#abd92d50b8571c253847b62c89b21133c", null ],
    [ "M_PI", "plplotP_8h.html#ae71449b1cc6e6250b91f539153a7a0d3", null ],
    [ "MAX", "plplotP_8h.html#afa99ec4acc4ecb2dc3c2d05da15d0e3f", null ],
    [ "MIN", "plplotP_8h.html#a3acffbd305ee72dcd4593c0d8af64a4f", null ],
    [ "NAFFINE", "plplotP_8h.html#abaf4ab9448cea14095ac91da69a6838e", null ],
    [ "ORIENTATION", "plplotP_8h.html#ac815b03ec48abf99301f44140ff0b0a9", null ],
    [ "PI", "plplotP_8h.html#a598a3330b3c21701223ee0ca14316eca", null ],
    [ "PIXELS_X", "plplotP_8h.html#a66d6dc4355bd8c6a9a28b79c59162928", null ],
    [ "PIXELS_Y", "plplotP_8h.html#af9852bb02ab4e984728d84e4e464d10d", null ],
    [ "pl_fgetpos", "plplotP_8h.html#a1746fea2cbee4c8b3bea3cb9e5368d13", null ],
    [ "PL_FILESIZE_KB", "plplotP_8h.html#a981a886d6a99eebc2bd4aaf96b744a4a", null ],
    [ "pl_fsetpos", "plplotP_8h.html#a3420ee76baf4c39a9ffc040436fb45ad", null ],
    [ "PL_MAXPOLY", "plplotP_8h.html#a3ae78f9d70f3b5ee8e7fb790665f7f75", null ],
    [ "PL_NSTREAMS", "plplotP_8h.html#ac7e5f6c5f87077c74bed1f3bcb54715d", null ],
    [ "PL_RGB_COLOR", "plplotP_8h.html#ad47775023e283082d2274c196ba264b8", null ],
    [ "PL_SFONT", "plplotP_8h.html#a3839f1d7a380f4ef20ebbddd7f275a27", null ],
    [ "PL_UNDEFINED", "plplotP_8h.html#aad52408b58851dc6713a87f439d0d926", null ],
    [ "PL_XFONT", "plplotP_8h.html#afa71ec0de00d1490f068a5a74903e07e", null ],
    [ "PLDI_DEV", "plplotP_8h.html#a5e4bab44736acafb8eeab671d011e9ce", null ],
    [ "PLDI_MAP", "plplotP_8h.html#a18c9e4a6b0aa1780aa6e72d4a54ad3f3", null ],
    [ "PLDI_ORI", "plplotP_8h.html#aa3fb844c1173fb26470f3b9386567fe1", null ],
    [ "PLDI_PLT", "plplotP_8h.html#ae0216a36024534929c94ff732870ff90", null ],
    [ "PLPLOT5_FONTS", "plplotP_8h.html#adddbf64c5ed632bfd3883b110cdf8fef", null ],
    [ "PLPLOT_BIN_ENV", "plplotP_8h.html#ac03c79ca8cd54fb9e7509706e7e68f0d", null ],
    [ "PLPLOT_DEFAULT_HEIGHT_MM", "plplotP_8h.html#ab2ace681fb9b3b392cba0f18bbe66071", null ],
    [ "PLPLOT_DEFAULT_HEIGHT_PIXELS", "plplotP_8h.html#a9e67a9eef9de5dc820c06f92a4f344b1", null ],
    [ "PLPLOT_DEFAULT_HEIGHT_POINTS", "plplotP_8h.html#a826fd901df2855ac98c9b33ec0b57fe3", null ],
    [ "PLPLOT_DEFAULT_PIXELS_PER_INCH", "plplotP_8h.html#ac3e74dd5ad2cabab8fe4652c29b6512b", null ],
    [ "PLPLOT_DEFAULT_WIDTH_MM", "plplotP_8h.html#a1d6d7570fcd62267241708091023650e", null ],
    [ "PLPLOT_DEFAULT_WIDTH_PIXELS", "plplotP_8h.html#a91cb3228499847af3a270c7b6ad19eb7", null ],
    [ "PLPLOT_DEFAULT_WIDTH_POINTS", "plplotP_8h.html#a7fcdda9368b70cb7ca54f5a74efe16c5", null ],
    [ "PLPLOT_HEIGHT_A4_MM", "plplotP_8h.html#a90709d034193dd5dfdbdedcc8d393b54", null ],
    [ "PLPLOT_HEIGHT_A5_MM", "plplotP_8h.html#a52ca90477cd17bcfc5315377db003d83", null ],
    [ "PLPLOT_HOME_ENV", "plplotP_8h.html#aa75c95ff00e85a94e00607777d07cae9", null ],
    [ "PLPLOT_LIB_ENV", "plplotP_8h.html#a4d712860a546e16091b8bfa9b6fb355f", null ],
    [ "PLPLOT_MAX_PATH", "plplotP_8h.html#a0b360f193f449275cbdc9b36a756dd6c", null ],
    [ "PLPLOT_MM_PER_INCH", "plplotP_8h.html#a3e57d03a5161d56776f4b8cbdd8532cc", null ],
    [ "PLPLOT_POINTS_PER_INCH", "plplotP_8h.html#a49a32722e9dcc0e01c3b3faee3ed082e", null ],
    [ "PLPLOT_TCL_ENV", "plplotP_8h.html#a7ec795052c6fe6de491ff626aae9a09b", null ],
    [ "PLPLOT_WIDTH_A4_MM", "plplotP_8h.html#a1e5f5dadc703e4a5c36491aab7ef692a", null ],
    [ "PLPLOT_WIDTH_A5_MM", "plplotP_8h.html#a9401bef8aac9d41473ed40dbf9878bce", null ],
    [ "plsetvar", "plplotP_8h.html#a4eeb27aac45f99ad72cc6da3115a587d", null ],
    [ "PLSTATE_CHR", "plplotP_8h.html#a466c3c0c53d46b141b3c1f4d46bc3456", null ],
    [ "PLSTATE_CMAP0", "plplotP_8h.html#a8d2bf416c54687c37054904f985fb13f", null ],
    [ "PLSTATE_CMAP1", "plplotP_8h.html#ad0a2af1aef551a9ccd4ca00c7fbbd834", null ],
    [ "PLSTATE_COLOR0", "plplotP_8h.html#aea93ee07e6a29ea6fdee6f1362104618", null ],
    [ "PLSTATE_COLOR1", "plplotP_8h.html#aa4d5d7ee225e17548f4066fc4bd27d4e", null ],
    [ "PLSTATE_FILL", "plplotP_8h.html#a32be3518883413bd04abf4243ee7abda", null ],
    [ "PLSTATE_SYM", "plplotP_8h.html#a6b3c4f17d069eafddc5971d9988fe5e4", null ],
    [ "PLSTATE_WIDTH", "plplotP_8h.html#a6d50332cd83f8d864604ff541655b2be", null ],
    [ "ROUND", "plplotP_8h.html#af6b649b1ed94420c340e1260e646dcc7", null ],
    [ "SIGN", "plplotP_8h.html#a8c4a9e5e4622948245de4ec0b5d38329", null ],
    [ "snprintf", "plplotP_8h.html#aa367b75c5aed883fef5befbdf04835a4", null ],
    [ "snscanf", "plplotP_8h.html#a690e5d3e324df4a0bcc627f25545943b", null ],
    [ "SSQR", "plplotP_8h.html#a527cd260524e42ed5b6c2ba9d638385a", null ],
    [ "TEXT_MODE", "plplotP_8h.html#a9a7cf845aad09d4e1b042b356a2ebb4e", null ],
    [ "TRANSFORM", "plplotP_8h.html#a70c974c9b1cf2464305b986b75c0865e", null ],
    [ "TRUE", "plplotP_8h.html#aa8cecfc5c5c054d2875c03e77b7be15d", null ],
    [ "VDPMM", "plplotP_8h.html#a62f0b85768cd2a99c9292043f9399f0f", null ],
    [ "CONT_LEVEL", "plplotP_8h.html#a554bcd61c1010c02fc4711a3541be30a", null ],
    [ "CONT_LINE", "plplotP_8h.html#af46feab5c736df8fe9a4406061ac7c69", null ],
    [ "DRV_INT", "plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06caa346c93ff529b2e76f26fff7dcb37c92", null ],
    [ "DRV_FLT", "plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06ca003e5f646837605b279c4a3e21a9e55d", null ],
    [ "DRV_STR", "plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06cac8cb0d9ed936be241f5a8d60e42056c2", null ],
    [ "cont_clean_store", "plplotP_8h.html#a1369d4790c599d92559808545b63f01d", null ],
    [ "cont_store", "plplotP_8h.html#ab31ef38f5bb56843df09bf42078665c5", null ],
    [ "difilt", "plplotP_8h.html#aeb14106a80979de5e9f0db61b38bbc11", null ],
    [ "difilt_clip", "plplotP_8h.html#a123456aef2077b98710c1945cc423716", null ],
    [ "grimage", "plplotP_8h.html#a3bb953b941f306756707370648093b64", null ],
    [ "label_box_custom", "plplotP_8h.html#abf89e2f3c6586e8f65a7cb9e03bc90ce", null ],
    [ "NoBufferNoPixmap", "plplotP_8h.html#a9b62a55b84cec4a17aedb04d620d46e0", null ],
    [ "pl_cpcolor", "plplotP_8h.html#a5a5a672a2b2a3513da5ca0e32209ad48", null ],
    [ "pl_create_tempfifo", "plplotP_8h.html#ad62d6a4c9eb019d77c1cec8d2d34f28a", null ],
    [ "pl_create_tempfile", "plplotP_8h.html#a3f8f961cbdb66cefd44f853e3f0895cc", null ],
    [ "pl_exit", "plplotP_8h.html#a2d4687ec27d861f778294d9473a169d8", null ],
    [ "plabort", "plplotP_8h.html#a35e0eff00813c22036a1c2d038d212f5", null ],
    [ "plcmap1_calc", "plplotP_8h.html#ae8a97df76143950564dfcd3816e3fd20", null ],
    [ "PLDLLIMPEXP_DATA", "plplotP_8h.html#a9343f56b51401cd1fecbf729753112aa", null ],
    [ "pldprec", "plplotP_8h.html#a65787139fccaa926cb497446f1701912", null ],
    [ "pldtfac", "plplotP_8h.html#ab3f8597dcfd3994254ba9865decdb5af", null ],
    [ "pldtik", "plplotP_8h.html#a04f05748c5a4733a92b2595887c0082e", null ],
    [ "plexit", "plplotP_8h.html#aca11cb4ac20a3feefd2d3408364310a5", null ],
    [ "plfill_soft", "plplotP_8h.html#ae4bcd3646ea1389b8f8f94d18f07e2fe", null ],
    [ "plfntld", "plplotP_8h.html#a24d750074d86147f34da1f107a1f88b1", null ],
    [ "plfontrel", "plplotP_8h.html#a87c8e3d2000c939fffb6d7d06ec52d21", null ],
    [ "plfvect", "plplotP_8h.html#a3b95a59549fdaee94cdcec7a6a7ae9ae", null ],
    [ "plHelpDrvOpts", "plplotP_8h.html#a689bfa46bb5ac678eb64c29dcd4a8900", null ],
    [ "plhershey2unicode", "plplotP_8h.html#a4c6015576cdec324212b66dfaa516c8f", null ],
    [ "plhrsh", "plplotP_8h.html#a6f17f9c4d5d0c7e73c09851f072fdfd5", null ],
    [ "plimageslow", "plplotP_8h.html#ad9285c1c1cee00084d0d264edcf888a1", null ],
    [ "plInBuildTree", "plplotP_8h.html#aa80648a5716299b7173be1e2bc591846", null ],
    [ "plio_fgets", "plplotP_8h.html#a10739c5e4b20a7692b85b5178640d7b7", null ],
    [ "plio_fread", "plplotP_8h.html#a6db2dcec8741ab31ebe1c730207b4b9f", null ],
    [ "plio_fwrite", "plplotP_8h.html#a1fd36c5dcb538d9f95c23d915f74fe1f", null ],
    [ "pllib_devinit", "plplotP_8h.html#a77a3382e0b51b2f438452e022bd4cbad", null ],
    [ "pllib_init", "plplotP_8h.html#a53902ab4f12b8699f46aa8c11c8689fc", null ],
    [ "plLibOpen", "plplotP_8h.html#a31d17dbc1aca95422473dbf4d4534a59", null ],
    [ "plP_affine_identity", "plplotP_8h.html#aae582b02f77fb4be7d2f205862549f41", null ],
    [ "plP_affine_multiply", "plplotP_8h.html#a48f15224c33dd13fecd8f4b7ca30be92", null ],
    [ "plP_affine_rotate", "plplotP_8h.html#a65e3c05e7d5fd74e2f224b70bb721c4c", null ],
    [ "plP_affine_scale", "plplotP_8h.html#ab5487c077d6a2e96424a01873afcc6ae", null ],
    [ "plP_affine_translate", "plplotP_8h.html#aca2df0605b6a1cab6395a5031dd88f75", null ],
    [ "plP_affine_xskew", "plplotP_8h.html#a4c190f9ac0d138cc2a3f3ca32da82fc4", null ],
    [ "plP_affine_yskew", "plplotP_8h.html#a0eee3fd8df3739d39dbf6b8ee1925a7b", null ],
    [ "plP_bop", "plplotP_8h.html#a485d2817b51a3d1031486682adaaed53", null ],
    [ "plP_checkdriverinit", "plplotP_8h.html#aca45ddfcca5aed11ab19be6911e4ebc1", null ],
    [ "plP_clip_poly", "plplotP_8h.html#af8b98ffdd53e711a23afd5c8c7e21d51", null ],
    [ "plP_clipline", "plplotP_8h.html#a80eb73ccd0471a66da970b574620c9eb", null ],
    [ "plP_dcmmx", "plplotP_8h.html#afaf6c8b672ca36b3a79b5731443ba288", null ],
    [ "plP_dcmmy", "plplotP_8h.html#ade9dc6e024833013fcaba7688fb72baa", null ],
    [ "plP_dcpcx", "plplotP_8h.html#a1bf39efbbac9d3ff9eb010ad54dffdcf", null ],
    [ "plP_dcpcy", "plplotP_8h.html#abb787422425cea9c2239132b7fa82f99", null ],
    [ "plP_dcscx", "plplotP_8h.html#a7e315ee534fa46032c5e4b016407f982", null ],
    [ "plP_dcscy", "plplotP_8h.html#a8f707c76f0aeb0bcfa3747b320bd7f87", null ],
    [ "plP_draphy", "plplotP_8h.html#afcf4a0fbaee4a71e704e03070501221b", null ],
    [ "plP_draphy_poly", "plplotP_8h.html#ad7659fc7e58a8dd05c41e6feccefb04a", null ],
    [ "plP_drawor", "plplotP_8h.html#a1f1ed49c980af9b6cd533f1a3acd799e", null ],
    [ "plP_drawor_poly", "plplotP_8h.html#a540ad13e35c747691393411baecf348c", null ],
    [ "plP_eop", "plplotP_8h.html#ab1e5007b5ce8c229f1ef969c3fbee0e7", null ],
    [ "plP_esc", "plplotP_8h.html#ad2f35ac89cd851e9db2f1eea32f9a799", null ],
    [ "plP_FCI2FontName", "plplotP_8h.html#a94bbf5280fb83c06d1692c43a2452c0f", null ],
    [ "plP_fci2hex", "plplotP_8h.html#abcf95f907cf9069ad658dce9c1e4d601", null ],
    [ "plP_fill", "plplotP_8h.html#ad90c1e7547061db7b8efffd6cf815bc3", null ],
    [ "plP_FreeDrvOpts", "plplotP_8h.html#a2e5a9fe18d203ca0d2c7a15076fb89cf", null ],
    [ "plP_gclp", "plplotP_8h.html#aba8054e2bee48e6669cb5143733d1b6d", null ],
    [ "plP_gdom", "plplotP_8h.html#a92153e7221efdcd457735fe191039024", null ],
    [ "plP_getinitdriverlist", "plplotP_8h.html#abf509829fea9edc8047ba4b7833bee6c", null ],
    [ "plP_gphy", "plplotP_8h.html#a6ae17a52598b15462e5d318f554cd89b", null ],
    [ "plP_gpixmm", "plplotP_8h.html#aed7b0fea39dc4311517455981c05b54a", null ],
    [ "plP_gprec", "plplotP_8h.html#ae9fccfe5d0e940c4fc23a113ebd6b4e1", null ],
    [ "plP_gradient", "plplotP_8h.html#a7ae0cb11419920fbbb90e999bd640820", null ],
    [ "plP_grange", "plplotP_8h.html#aa297cded85840cc10694d08344150ea6", null ],
    [ "plP_gsub", "plplotP_8h.html#a26b65cc5d4ef0a9184e846eae3d11cff", null ],
    [ "plP_gtimefmt", "plplotP_8h.html#af213da8a938ddcd7c7892c2fb9875e33", null ],
    [ "plP_gw3wc", "plplotP_8h.html#a755afa15a4e42c0d16deb69ceddc3717", null ],
    [ "plP_gzback", "plplotP_8h.html#a0aa809d1a16db6afa351ec92f659f091", null ],
    [ "plP_hex2fci", "plplotP_8h.html#a99c7073577aa3feda05b96e5dac0a791", null ],
    [ "plP_image", "plplotP_8h.html#a49cb4f889b6918c113d8f1ee8d9ba00f", null ],
    [ "plP_init", "plplotP_8h.html#a1c04ae2f68d0b377a5f6f6c97474498c", null ],
    [ "plP_line", "plplotP_8h.html#a4f9a6519caa1e25137cf95fdd2e5860d", null ],
    [ "plP_mmdcx", "plplotP_8h.html#a6b1274b1f156e3cad3b67fcc6e339ca4", null ],
    [ "plP_mmdcy", "plplotP_8h.html#a57e69492885873ac1755055a1548715b", null ],
    [ "plP_mmpcx", "plplotP_8h.html#aa41e5389242737ec430ae87346adbea0", null ],
    [ "plP_mmpcy", "plplotP_8h.html#ad94d4b939139492d3235dc023df433c3", null ],
    [ "plP_movphy", "plplotP_8h.html#a7714c8a90177014b0b5b541093c9ffc9", null ],
    [ "plP_movwor", "plplotP_8h.html#a3b767a0c2407e00d90195fa6fed1bf67", null ],
    [ "plP_pcdcx", "plplotP_8h.html#aa065b2459ef0397308754b1e1079db33", null ],
    [ "plP_pcdcy", "plplotP_8h.html#a7be79974555917c614d252126ced3c20", null ],
    [ "plP_plfclp", "plplotP_8h.html#a0531fd7924d4b2e9c2570f6ec7aeb507", null ],
    [ "plP_pllclp", "plplotP_8h.html#a4f34e7e8f5427783cb8fc89d460a3ec5", null ],
    [ "plP_pointinpolygon", "plplotP_8h.html#ae5bc736692ac9c73764b7eb6585cf97a", null ],
    [ "plP_polyline", "plplotP_8h.html#a1aba6c2de9e2d7f7e74589b909e20a49", null ],
    [ "plP_scdcx", "plplotP_8h.html#a25b8ea175a717e1e9bb83b3478df41db", null ],
    [ "plP_scdcy", "plplotP_8h.html#a8f9e4adf283a1979c12e5cf885510a0e", null ],
    [ "plP_sclp", "plplotP_8h.html#ac32d67d524a27bf32953485ba7945977", null ],
    [ "plP_script_scale", "plplotP_8h.html#a4c34fa7e0f9f593c902d391d2c948aec", null ],
    [ "plP_setphy", "plplotP_8h.html#a54a64c364463ca68c93443be2eb116e7", null ],
    [ "plP_setpxl", "plplotP_8h.html#adf6f975d19dac812b4a2639d3a2b88e5", null ],
    [ "plP_setsub", "plplotP_8h.html#a117b8b993c854bc0e2f68c1f3483201c", null ],
    [ "plP_ssub", "plplotP_8h.html#a1f7cb220888fd00e4aa6b33a499dee8c", null ],
    [ "plP_state", "plplotP_8h.html#af52a8d24cb23cb455d10983c18cbf6e0", null ],
    [ "plP_stindex", "plplotP_8h.html#a3f50d12313fafdb69940ee278cb5df29", null ],
    [ "plP_strpos", "plplotP_8h.html#ae61bc6b9da780fda49b1754b59e161ac", null ],
    [ "plP_stsearch", "plplotP_8h.html#ab8d5b382b940de087c67fd9c278dd285", null ],
    [ "plP_subpInit", "plplotP_8h.html#a60303902fa8f1b50e0e3711f41f7fadf", null ],
    [ "plP_swin", "plplotP_8h.html#a93ba5ed9e5f7401b4f489dbd6758c8aa", null ],
    [ "plP_text", "plplotP_8h.html#a2a160696d430297f433fe017de408b06", null ],
    [ "plP_tidy", "plplotP_8h.html#a58a3581c01cee21a43d2cceb63861cac", null ],
    [ "plP_w3wcx", "plplotP_8h.html#a7bdfc2321dda486d861347e121845c42", null ],
    [ "plP_w3wcy", "plplotP_8h.html#ad800713c5dc0e318c32fb6f40500ee20", null ],
    [ "plP_w3wcz", "plplotP_8h.html#a9435c383222dacc441b183a6c9a3baf6", null ],
    [ "plP_wait", "plplotP_8h.html#aece4a4c7e68319428d16631e0d73c5d0", null ],
    [ "plP_wcdcx", "plplotP_8h.html#a22947e804c7a308ee6b3e6cdd89ce03d", null ],
    [ "plP_wcdcy", "plplotP_8h.html#a2c3c42ee72261fa6574dcb47467e7a19", null ],
    [ "plP_wcmmx", "plplotP_8h.html#ad06171b8cbf905302f33b8ea898b5d96", null ],
    [ "plP_wcmmy", "plplotP_8h.html#a9096fa9790ff1a9a970f47fb1ed17681", null ],
    [ "plP_wcpcx", "plplotP_8h.html#ad63d39fa7686f9d63f742aaa893015b9", null ],
    [ "plP_wcpcy", "plplotP_8h.html#a44f258a39516082c224041ff250a02b6", null ],
    [ "plP_xgvpw", "plplotP_8h.html#a196e425a581d271af68ac89071ffe190", null ],
    [ "plParseDrvOpts", "plplotP_8h.html#a4fd8b6fe34a9203230ec0ee61997d165", null ],
    [ "plreadmetafile", "plplotP_8h.html#a0516d780452e9ab78b31e8dfbad9973b", null ],
    [ "plrestore_locale", "plplotP_8h.html#a774dd4dd367a4c8695730246cbfffef4", null ],
    [ "plRotationShear", "plplotP_8h.html#aaeeeedfb840b832ab1fee2b55ac1591a", null ],
    [ "plsave_set_locale", "plplotP_8h.html#a43d4c825760173fd9980f840ff3b4683", null ],
    [ "plsnprintf", "plplotP_8h.html#a3e82cbc1c6f5f241088200eba4f3eb4c", null ],
    [ "plsnscanf", "plplotP_8h.html#a83e193a36aa2ff36eeb3bac560b0fad2", null ],
    [ "plstik", "plplotP_8h.html#acc2c4d27dede240dfff47df0597413b7", null ],
    [ "plstr", "plplotP_8h.html#a1ed2476ebb26f491f69b2a1530b3549a", null ],
    [ "plstrdup", "plplotP_8h.html#a626af54723e59fc91744971f63f35942", null ],
    [ "plstrl", "plplotP_8h.html#a7ca0093abd2c4969818b16c24bc69144", null ],
    [ "plstrm_init", "plplotP_8h.html#a659bd03250b8cee5bc6dd32d0e81a200", null ],
    [ "plwarn", "plplotP_8h.html#a7b4834689ffbd72c3b9a9dd6bf782fe5", null ],
    [ "plwxtik", "plplotP_8h.html#ac1919aee4a3ac0ce8f8ce97fd353d224", null ],
    [ "plwytik", "plplotP_8h.html#a3cf0d579677a727ac4f3eccad1cecbc2", null ],
    [ "plxtik", "plplotP_8h.html#a47734cc23885611abbeee1807b648365", null ],
    [ "plytik", "plplotP_8h.html#a860083c73dd16d789fab244305b4afdd", null ],
    [ "RestoreWrite2BufferPixmap", "plplotP_8h.html#a429babb5efcabc2bba8944f399fe8866", null ],
    [ "ucs4_to_utf8", "plplotP_8h.html#a2f6d100c298c3699996281a98f0e019f", null ],
    [ "hershey_to_unicode_lookup_table", "plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43", null ],
    [ "number_of_entries_in_hershey_to_unicode_table", "plplotP_8h.html#a578920bffd5cd2221fa8c60e7d35e7ec", null ],
    [ "plP_greek_mnemonic", "plplotP_8h.html#a4e3b3e20867b5eb19bc1ea4014e0c7ec", null ]
];